# How can the RMSE be interpreted?
import numpy as np
from layup_search_funcs import *

# define a random layup(s)
layers = 12 # number of layups
num = 100 # number of randomly generated laminates

de = 1 # delta angle in DEG
ang = np.int32(np.floor(180/de)) # number of angles in domain

lams = np.random.random_sample(layers * num).reshape(-1, num).T
lams = np.deg2rad(np.rint((lams*(ang-1))*de-(90-de)))

# get its LP set
lps = calc_lp_array(lams)

# offset layup by some angle
err_ang = 1/12 # error angle in DEG
err_lams = lams + np.deg2rad(err_ang) # offset lams (all are offset by same angle)
err_lps = calc_lp_array(err_lams) # compute lp sets for error laminates

# calc the RMSE
MSE = np.sum((lps-err_lps)**2, axis=1)/12
RMSE = np.sqrt(MSE) 

print(np.mean(RMSE))
