# simple example of layup search
# input: LP set
# output: found layups

import numpy as np
from layup_search_funcs import *
import time
import pandas as pd

# define LP set
# A. D. Viquerat, A continuation-based method for finding laminated com-posite stacking sequences,
# Composite Structures 238 (2020) 111872.doi:10.1016/j.compstruct.2020.111872
lps1 = np.array([0.2, -0.05, -0.15, -0.1, 0.4, 0.2, 0.4, 0.25, 0.2, 0.2, -0.05, -0.1])

# Sprengholz et al., Rapid Transformation of Lamination Parameters into Continuous StackingSequences
# Composite Structures XXXXXXX
# t = 5.97mm equal to 48 plies at t_ply = 0.125mm
lps2 = np.array([1.78442546e-01,  1.11641790e-02, -7.14012762e-01, 2.13190267e-02,
                 3.65073530e-04, -2.59523619e-06,  3.56051502e-03, 1.25783705e-03,
                 2.26258560e-02,  1.16385360e-01, -1.00000000e+00, 7.65404249e-18])

# Solution of Liu with 12 layers (t_ply = 0.5mm), (Lius Error):
# ([45, -45, -45, 45, 45, 0, 0, -45, -45, 45, -45, 45], 0.17432280337059863)
# Lius MSE: 0.00038844368320071983
# Lius RMSE: 0.019708974686693366

np.savetxt("lp_1.csv", lps1.reshape((1,12)), delimiter=",", fmt='%6.4f')
np.savetxt("lp_2.csv", lps2.reshape((1,12)), delimiter=",", fmt='%6.4f')

# Chose LP set: Viquerat (lps1) or Sprengholz et. al (lps2)
lps = lps1

# start search and record time
stime = time.time() # check how long the search takes
sol, timestamps = search_layup(lps, 12, delta_doe=11.25, it_comb=100, eps=0.043, error=1e-6, it_sub=3, it_s=3, it_n=1, delta_s=3, delta_n=1, steps_n=3, doe=False, disp=True)
etime = time.time()
print("Time to completion: ", np.around(etime-stime, 1), "s")
print("Number of found layups: ", sol.shape[0])

# compute errors, append to csv output
MSE = np.sum((lps-calc_lp_array(np.deg2rad(sol)))**2, axis=1)/12
RMSE = np.sqrt(MSE) 
#print(RMSE)

# round solutions to 1 decimal
sol = np.around(sol, 1)

# print values to csv file
df = pd.DataFrame(np.column_stack((sol, RMSE)))
df.to_csv("LP_set_viquerat_12_layer_layups_temp.csv", sep=';', index=True, header=False, float_format='%.10f') # set index to true to get number of solution -> easier table generation
ts = pd.DataFrame(timestamps) # print timestamps for individual solutions out to csv
ts.to_csv("LP_set_viquerat_12_layer_timestamps_temp.csv.csv", sep=';', index=True, header=False)

